==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Definições do monitorizador de energia</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Ativar monitorizador de energia</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Aviso:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>O nível está baixo em:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Utilizar ícones do tema:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Se a energia estiver baixa:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Mostrar ícone:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ativar monitori&amp;zador de inatividade</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Se existir inatividade:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Tempo para inatividade:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> minutos</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ativar monitori&amp;zador da tampa</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Ação ao fechar a tampa</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Com bateria</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Nada fazer</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Com corrente</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>Ao &amp;utilizar monitor externo</translation>
    </message>
    <message>
        <source>On Ac</source>
        <translation type="vanished">Com corrente</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>LXQt Powermanagement Configuration</source>
        <translation type="vanished">Configuração do gestor de energia do LXQt</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Tampa</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>idle</source>
        <translation type="vanished">inatividade</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Nada fazer</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Bloquear ecrã</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Definições do monitorizador de energia</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>Ativar mo&amp;nitorizador de energia</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Aviso:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>O nível está baixo em:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Utilizar ícones do tema:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>A carregar</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>A descarregar</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Se a energia estiver baixa:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Mostrar ícone:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>incorporada</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Nível: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ativar monitori&amp;zador de inatividade</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Se existir inatividade:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Tempo para inatividade:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> minutos</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ativar monitori&amp;zador da tampa</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Ação ao fechar a tampa</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Com bateria</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Nada fazer</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Com corrente</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>Ao &amp;utilizar monitor externo</translation>
    </message>
    <message>
        <source>On Ac</source>
        <translation>Com corrente</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>LXQt Powermanagement Configuration</source>
        <translation>Configuração do gestor de energia do LXQt</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Definições de energia</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Tampa</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Inatividade</translation>
    </message>
    <message>
        <source>idle</source>
        <translation>inatividade</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Nada fazer</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Bloquear ecrã</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
</context>
</TS>
